@@ -2,7 +2,7 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '1.27';
+our $VERSION = '1.28';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Test::SharedFork 0.12;
@@ -23,18 +23,26 @@ sub test_tcp {
     for my $k (qw/client server/) {
         die "missing madatory parameter $k" unless exists $args{$k};
     }
+    my $server_code = delete $args{server};
+    my $port = $args{port} || empty_port();
+
+    my $client_code = delete $args{client};
+
     my $server = Test::TCP->new(
-        code => $args{server},
-        port => $args{port} || empty_port(),
+        code => $server_code,
+        port => $port,
+        %args,
     );
-    $args{client}->($server->port, $server->pid);
+    $client_code->($server->port, $server->pid);
     undef $server; # make sure
 }
 
 sub wait_port {
-    my $port = shift;
+    my ($port, $sleep, $retry) = @_;
+    $sleep ||= 0.001;
+    $retry ||= 100;
 
-    Net::EmptyPort::wait_port($port, 0.001, 100)
+    Net::EmptyPort::wait_port($port, $sleep, $retry)
         or die "cannot open port: $port";
 }
 
@@ -47,6 +55,8 @@ sub new {
     Carp::croak("missing mandatory parameter 'code'") unless exists $args{code};
     my $self = bless {
         auto_start => 1,
+        wait_port_sleep => 0.001,
+        wait_port_retry => 100,
         _my_pid    => $$,
         %args,
     }, $class;
@@ -64,7 +74,7 @@ sub start {
     if ( my $pid = fork() ) {
         # parent.
         $self->{pid} = $pid;
-        Test::TCP::wait_port($self->port);
+        Test::TCP::wait_port($self->port, $self->{wait_port_sleep}, $self->{wait_port_retry});
         return;
     } elsif ($pid == 0) {
         # child process
@@ -201,8 +211,11 @@ Functional interface.
         },
         # optional
         port => 8080
+        wait_port_sleep => 0.001,
+        wait_port_retry => 100,
     );
 
+
 =item wait_port
 
     wait_port(8080);
@@ -235,6 +248,22 @@ The callback function. Argument for callback function is: C<< $code->($pid) >>.
 
 This parameter is required.
 
+=item $args{wait_port_retry} : Number
+
+Retry C<$wait_port_retry> times in waiting ports.
+
+See also L<Net::EmptyPort>.
+
+I<Default: 0.001>
+
+=item $args{wait_port_sleep} : Number
+
+Sleep C<$wait_port_sleep> seconds before checking port.
+
+See also L<Net::EmptyPort>.
+
+I<Default: 100>
+
 =back
 
 =item $server->start()
